@@ -334,13 +334,11 @@ class Transient(Module):
                     'times']) for x in time_list] + [
                         x for x in self._data['times']]
             elif time_unit == 'phase':
-                if 'maxdate' not in self._data or not len(self._data[
-                        'maxdate']) or 'value' not in self._data['maxdate'][0]:
+                if 'maxdate' not in self._data:
                     raise(prt.message('no_maxdate', name))
-                max_mjd = astrotime(self._data['maxdate'][0]['value'].replace(
+                max_mjd = astrotime(self._data['maxdate'].replace(
                     '/', '-')).mjd
-                alltimes = [x + max_mjd - min(self._data[
-                    'times']) for x in time_list] + [
+                alltimes = [x + max_mjd for x in time_list] + [
                         x for x in self._data['times']]
             else:
                 raise('Unknown `time_unit`.')
@@ -362,7 +360,7 @@ class Transient(Module):
             obslist.sort()
 
             # Save these fake observations under keys with `extra_` prefix.
-            if len(obslist):
+            if obslist:
                 for x, y in zip(self._OBS_KEYS, zip(*obslist)):
                     self._data['extra_' + x] = y
 
@@ -370,7 +368,7 @@ class Transient(Module):
             if 'upperlimits' in self._data:
                 new_vals = np.array(self._data[qkey])[
                     np.array(self._data['upperlimits']) != True]  # noqa E712
-                if len(new_vals):
+                if new_vals.size:
                     self._data['min_' + qkey] = min(new_vals)
                     self._data['max_' + qkey] = max(new_vals)
             minv = self._data['min_' + qkey]
